"""Contains the class that represents the AWS Step Functions Succeed State"""
from typing import Dict

from .base import State


class SucceedState(State):
    """Succeed state

    A Succeed state stops the state machine and marks it successful. Succeed states are
    generated by including a ``return`` statement in an .sfn file.

    See: https://docs.aws.amazon.com/step-functions/latest/dg/amazon-states-language-succeed-state.html

    For example::

        return

    resolves to::

        {
            "Type": "Succeed"
        }
    """

    TERMINAL = True

    def to_dict(self) -> Dict:
        """Return a serialized representation of this Succeed state."""
        return {"Type": "Succeed"}
